@@ -6,7 +6,8 @@ import hashlib
 import json
 from json2html import *
 import os
-import pickle5 as pickle
+# import pickle5 as pickle
+import pickle
 from pkg_resources import parse_version
 import subprocess
 import sys
